@@ -278,10 +278,15 @@ class UpdateManager(Gtk.Window):
                 self.oem_metapackages.add(pkg)
 
     def _fetch_ua_updates(self):
-        self.ua_updates = ua.updates().updates
+        try:
+            self.ua_updates = ua.updates().updates
+        except Exception as e:
+            print("Error running updates end-point: ", e)
+            self.ua_updates = []
 
     def _get_ua_security_status(self):
         self.ua_security_packages = []
+        self.ua_updates = []
         t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
         t.start()
         while t.is_alive():
@@ -317,7 +322,7 @@ class UpdateManager(Gtk.Window):
         error_occurred=False,
     ):
         self._check_hwe_support_status()
-        if install_count != 0 or len(self.ua_security_packages) > 0:
+        if install_count != 0:
             header = None
             desc = None
             if error_occurred:
