@@ -308,7 +308,9 @@ class UpdatesAvailable(InternalDialog):
 
         pkg_toggle_renderer = Gtk.CellRendererToggle()
         pkg_toggle_renderer.set_property("ypad", 2)
-        pkg_toggle_renderer.connect("toggled", self.on_update_toggled)
+        pkg_toggle_renderer.connect(
+            "toggled", self.on_update_toggled, self.treeview_update
+        )
         pkg_column.pack_start(pkg_toggle_renderer, False)
         pkg_column.add_attribute(
             pkg_toggle_renderer, "active", LIST_TOGGLE_ACTIVE
@@ -607,6 +609,13 @@ class UpdatesAvailable(InternalDialog):
         model = widget.get_model()
         iter = model.get_iter(path)
 
+        # Screen reader: Speak state of toggle box
+        ac = widget.get_accessible()
+        if model.get_value(iter, LIST_TOGGLE_ACTIVE):
+            ac.emit("notification", _("Selected"), 0)
+        else:
+            ac.emit("notification", _("Unselected"), 0)
+
         # set descr
         data = model.get_value(iter, LIST_UPDATE_DATA)
         item = data.item
@@ -819,6 +828,7 @@ class UpdatesAvailable(InternalDialog):
         self.hbox_restart.set_visible(requires_restart)
 
     def _refresh_updates_count(self):
+        self.button_install.show()
         self.button_install.set_sensitive(
             self.cache.install_count + self.cache.del_count
         )
@@ -854,7 +864,7 @@ class UpdatesAvailable(InternalDialog):
                       and not self.list.ubuntu_pro_groups):
                     download_str = _("You need to enable Ubuntu Pro to install"
                                      " these updates.")
-                    self.button_install.destroy()
+                    self.button_install.hide()
                 else:
                     download_str = _("There are no updates to install.")
                     self.button_install.set_sensitive(False)
@@ -1065,7 +1075,7 @@ class UpdatesAvailable(InternalDialog):
             self.hbox_on_3g.hide()
             self.hbox_roaming.hide()
 
-    def on_update_toggled(self, renderer, path):
+    def on_update_toggled(self, renderer, path, treeview):
         """a toggle button in the listview was toggled"""
         iter = self.store.get_iter(path)
         data = self.store.get_value(iter, LIST_UPDATE_DATA)
@@ -1080,12 +1090,19 @@ class UpdatesAvailable(InternalDialog):
         else:
             self.toggle_from_items([data.item])
 
+        # Screen reader: Speak state of toggle box
+        ac = treeview.get_accessible()
+        if self.store.get_value(iter, LIST_TOGGLE_ACTIVE):
+            ac.emit("notification", _("Selected"), 0)
+        else:
+            ac.emit("notification", _("Unselected"), 0)
+
     def on_treeview_update_row_activated(self, treeview, path, column, *args):
         """
         If an update row was activated (by pressing space), toggle the
         install check box
         """
-        self.on_update_toggled(None, path)
+        self.on_update_toggled(None, path, treeview)
 
     def toggle_from_items(self, items):
         self.setBusy(True)
