@@ -15,13 +15,8 @@
 
 """A test plugin."""
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 __metaclass__ = type
-__all__ = [
-    'CharlieCruft',
-    'CharliePlugin',
-]
+__all__ = ["CharlieCruft", "CharliePlugin"]
 
 from janitor.plugincore.cruft import Cruft
 from janitor.plugincore.plugin import Plugin
@@ -32,11 +27,11 @@ class CharlieCruft(Cruft):
         self.app = app
 
     def get_shortname(self):
-        return 'Charlie'
+        return "Charlie"
 
     def cleanup(self):
         # Tell the app we're cleaning up this cruft.
-        self.app.notifications.append((self, 'cruft'))
+        self.app.notifications.append((self, "cruft"))
 
 
 class CharliePlugin(Plugin):
@@ -44,4 +39,4 @@ class CharliePlugin(Plugin):
         yield CharlieCruft(self.app)
 
     def post_cleanup(self):
-        self.app.notifications.append((self, 'post'))
+        self.app.notifications.append((self, "post"))
